==> types_boto3_emr-1.35.71-py3-none-any.whl: types_boto3_emr/waiter.py <==
"""
Type annotations for emr service client waiters.

[Open documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_emr.client import EMRClient
    from types_boto3_emr.waiter import (
        ClusterRunningWaiter,
        ClusterTerminatedWaiter,
        StepCompleteWaiter,
    )

    session = Session()
    client: EMRClient = session.client("emr")

    cluster_running_waiter: ClusterRunningWaiter = client.get_waiter("cluster_running")
    cluster_terminated_waiter: ClusterTerminatedWaiter = client.get_waiter("cluster_terminated")
    step_complete_waiter: StepCompleteWaiter = client.get_waiter("step_complete")
    ```

Copyright 2024 Vlad Emelianov
"""

import sys

from botocore.waiter import Waiter

from .type_defs import (
    DescribeClusterInputClusterRunningWaitTypeDef,
    DescribeClusterInputClusterTerminatedWaitTypeDef,
    DescribeStepInputStepCompleteWaitTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ClusterRunningWaiter", "ClusterTerminatedWaiter", "StepCompleteWaiter")


class ClusterRunningWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr/waiter/ClusterRunning.html#EMR.Waiter.ClusterRunning)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/#clusterrunningwaiter)
    """

    def wait(self, **kwargs: Unpack[DescribeClusterInputClusterRunningWaitTypeDef]) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr/waiter/ClusterRunning.html#EMR.Waiter.ClusterRunning.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/#clusterrunningwaiter)
        """


class ClusterTerminatedWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr/waiter/ClusterTerminated.html#EMR.Waiter.ClusterTerminated)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/#clusterterminatedwaiter)
    """

    def wait(self, **kwargs: Unpack[DescribeClusterInputClusterTerminatedWaitTypeDef]) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr/waiter/ClusterTerminated.html#EMR.Waiter.ClusterTerminated.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/#clusterterminatedwaiter)
        """


class StepCompleteWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr/waiter/StepComplete.html#EMR.Waiter.StepComplete)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/#stepcompletewaiter)
    """

    def wait(self, **kwargs: Unpack[DescribeStepInputStepCompleteWaitTypeDef]) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr/waiter/StepComplete.html#EMR.Waiter.StepComplete.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/#stepcompletewaiter)
        """

==> types_boto3_emr-1.35.93-py3-none-any.whl: types_boto3_emr/waiter.py <==
"""
Type annotations for emr service client waiters.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/)

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_emr.client import EMRClient
    from types_boto3_emr.waiter import (
        ClusterRunningWaiter,
        ClusterTerminatedWaiter,
        StepCompleteWaiter,
    )

    session = Session()
    client: EMRClient = session.client("emr")

    cluster_running_waiter: ClusterRunningWaiter = client.get_waiter("cluster_running")
    cluster_terminated_waiter: ClusterTerminatedWaiter = client.get_waiter("cluster_terminated")
    step_complete_waiter: StepCompleteWaiter = client.get_waiter("step_complete")
    ```

Copyright 2025 Vlad Emelianov
"""

from __future__ import annotations

import sys

from botocore.waiter import Waiter

from .type_defs import DescribeClusterInputWaitTypeDef, DescribeStepInputWaitTypeDef

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = ("ClusterRunningWaiter", "ClusterTerminatedWaiter", "StepCompleteWaiter")


class ClusterRunningWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr/waiter/ClusterRunning.html#EMR.Waiter.ClusterRunning)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/#clusterrunningwaiter)
    """

    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeClusterInputWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr/waiter/ClusterRunning.html#EMR.Waiter.ClusterRunning.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/#clusterrunningwaiter)
        """


class ClusterTerminatedWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr/waiter/ClusterTerminated.html#EMR.Waiter.ClusterTerminated)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/#clusterterminatedwaiter)
    """

    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeClusterInputWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr/waiter/ClusterTerminated.html#EMR.Waiter.ClusterTerminated.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/#clusterterminatedwaiter)
        """


class StepCompleteWaiter(Waiter):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr/waiter/StepComplete.html#EMR.Waiter.StepComplete)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/#stepcompletewaiter)
    """

    def wait(  # type: ignore[override]
        self, **kwargs: Unpack[DescribeStepInputWaitTypeDef]
    ) -> None:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/emr/waiter/StepComplete.html#EMR.Waiter.StepComplete.wait)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_emr/waiters/#stepcompletewaiter)
        """
